@@ -35,10 +35,18 @@ class fMMS_config:
 			self.set_img_resize_width(0)
 		if self.get_version() == None:
 			self.set_version("Unknown")
+		if self.get_db_path() == None:
+			self.set_db_path("/home/user/.fmms/mms.db")
 		
 	def read_config(self):
 		pass
 	
+	def set_db_path(self, path):
+		self.client.set_string(self._fmmsdir + "db", path)
+	
+	def get_db_path(self):
+		return self.client.get_string(self._fmmsdir + "db")
+	
 	def get_version(self):
 		return self.client.get_string(self._fmmsdir + "version")
 	
