@@ -702,9 +702,9 @@ class fMMS_GUI(hildon.Program):
 
 	def run(self):
 		self.window.show_all()
-		gtk.gdk.threads_enter()
+		#gtk.gdk.threads_enter()
 		gtk.main()
-		gtk.gdk.threads_leave()
+		#gtk.gdk.threads_leave()
 		
 if __name__ == "__main__":
 	app = fMMS_GUI()
