@@ -203,7 +203,9 @@ class PushHandler:
 				#mmsdata = opener.open(location)
 				urllib2.install_opener(opener)
 				
-			headers = {'x-wap-profile': 'http://mms.frals.se/n900.rdf'}
+			#headers = {'x-wap-profile': 'http://mms.frals.se/n900.rdf'}
+			#User-Agent: NokiaN95/11.0.026; Series60/3.1 Profile/MIDP-2.0 Configuration/CLDC-1.1 
+			headers = {'User-Agent' : 'Nokia RX-51/N900', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf', 'Profile' : 'http://mms.frals.se/n900.rdf'}
 			req = urllib2.Request(location, headers=headers)
 			mmsdata = urllib2.urlopen(req)
 			try:
@@ -373,8 +375,9 @@ class MMSSender:
 		fp.close()
 		### END TEMP CODE ###
 		
-		#headers = {'Content-Type':'application/vnd.wap.mms-message', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
-		headers = {'Content-Type':'application/vnd.wap.mms-message'}
+		#User-Agent: NokiaN95/11.0.026; Series60/3.1 Profile/MIDP-2.0 Configuration/CLDC-1.1 
+		headers = {'Content-Type':'application/vnd.wap.mms-message', 'User-Agent' : 'Nokia RX-51/N900', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf', 'Profile' : 'http://mms.frals.se/n900.rdf'}
+		#headers = {'Content-Type':'application/vnd.wap.mms-message'}
 		if proxyurl == "" or proxyurl == None:
 			print "connecting without proxy"
 			mmsc = mmsc.replace("http://", "")
